# Card Data & Models

---

The following models pertain to Smartcard information & related. See also: [Operations/Cards](../operators/cards.md).

## Card Model (`SmartCard()`)

::: gpyg.models.SmartCard

---

## Other Types

::: gpyg.models.Sex

::: gpyg.models.PinData

::: gpyg.models.UIFData

::: gpyg.models.KeyData